@@ -1,11 +1,12 @@
 import json
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
 from t2wml.mapping.kgtk import create_kgtk
+
 from t2wml.wikification.item_table import Wikifier
 from t2wml.spreadsheets.sheet import Sheet
 from t2wml.mapping.statement_mapper import YamlMapper, StatementMapper
 from t2wml.mapping.canonical_spreadsheet import create_canonical_spreadsheet
-from t2wml.utils.debug_logging import basic_debug
+
 
 class KnowledgeGraph:
     """A knowledge graph (collection of statements) created from inputs. Also included errors and metadata.
@@ -51,8 +52,7 @@ class KnowledgeGraph:
         statement, errors = statement_mapper.get_cell_statement(sheet, wikifier, col, row, do_init=True)
 
     @classmethod
-    @basic_debug
-    def generate(cls, statement_mapper:StatementMapper, sheet:Sheet, wikifier:Wikifier, start=0, end=None):
+    def generate(cls, statement_mapper:StatementMapper, sheet:Sheet, wikifier:Wikifier, start=0, end=None, count=None):
         """create a KnowledgeGraph instance from API classes
 
         Args:
@@ -63,7 +63,7 @@ class KnowledgeGraph:
         Returns:
             KnowledgeGraph: an initialized KnowledgeGraph instance
         """
-        statements, errors, metadata = statement_mapper.get_statements(sheet, wikifier, start, end)
+        statements, errors, metadata = statement_mapper.get_statements(sheet, wikifier, start, end, count)
         return cls(statements, errors, metadata, sheet)
 
     @classmethod
