@@ -59,7 +59,7 @@ def validate_id(node_id):
 
 @basic_debug
 def kgtk_to_dict(file_path):
-    #if label is P2010050001 (datamart tag), the key is tags and a list is generated
+    #if label is P2010050001 (datamart tag), the key is tags and a dict is generated
     input_dict=defaultdict(dict)
     input_dict["filepath"]=dict(node1="", node2="", value=file_path)
     with open(file_path, 'r', encoding="utf-8") as f:
@@ -69,10 +69,15 @@ def kgtk_to_dict(file_path):
             label = row_dict["label"]
             value = row_dict["node2"]
             if label == "P2010050001":
-                if "tags" in input_dict[node1]:
-                    input_dict[node1]["tags"].append(value)
-                else:
-                    input_dict[node1]["tags"]=[value]
+                if ":" in value:
+                    key, val = value.split(":", 1)
+                    try:
+                        input_dict[node1]["tags"][key]=val
+                    except KeyError:
+                        input_dict[node1]["tags"]={key:val}
+                else: 
+                    print("malformed tag: ", value)
+
             else:
                 input_dict[node1][label]=value
     return dict(input_dict)
@@ -85,7 +90,9 @@ def dict_to_kgtk(in_dict, out_path):
     for node1, node_dict in in_dict.items():
         for label, value in node_dict.items():
             if label=="tags":
-                for index, tag in enumerate(value):
+                tag_dict=value
+                for index, tag_key in enumerate(tag_dict):
+                    tag= tag_key + ":" + tag_dict[tag_key]
                     tsv_dict_arr.append(dict(node1=node1, label="P2010050001", node2=tag, id=f'{node1}-{label}-{index}'))
             else:
                 tsv_dict_arr.append(dict(node1=node1, label=label, node2=value, id=f'{node1}-{label}'))
